@@ -167,6 +167,30 @@ class Configuration:
             else:
                 raise Exception('No Input Provided')
 
+            self._validate_params()
+
+        def _validate_params(self):
+            if not self.ssh_user and not self.ssh_key:
+                auth_method = self._get_auth_method('user', 'key')
+                self._validate_auth_method(auth_method)
+            if not self.elevation_pass:
+                self.elevation_pass = getpass('Please enter your elevation (sudo) password: ')
+
+        def _get_auth_method(self, *auth_methods, retry_limit=3, retry_count=0):
+            print('No Authentication Method Found. Please enter either "user" or "key" to provide that authentication method')
+            auth_method = input('? ').lower()
+            if auth_method not in auth_methods:
+                if retry_count >= retry_limit:
+                    raise Exception("Invalid Authentication Method Provided")
+                self._get_auth_method(auth_methods, retry_limit, retry_count + 1)
+        
+        def _validate_auth_method(self, auth_method):
+            if auth_method.lower() == 'user':
+                self.ssh_user = input('Please enter username: ')
+                self.ssh_user_password = getpass(f"Please enter {self.ssh_user}'s password: ")
+            if auth_method.lower() == 'key':
+                self.ssh_key = input('Please enter ssh_key path (or enter default to attempt auto retrieval of key): ')
+
         def get_run_command(self, dal):
             raise NotImplementedError('Connection Configuration Is Not Runnable')
 
@@ -454,7 +478,11 @@ class Configuration:
             shell_dependencies = self.__create_users(connection_setup['users'])
 
         if 'dependencies' in connection_setup.keys():
-            [self.server_config.add_dependency(shell_dependency) for shell_dependency in shell_dependencies]
+            try:
+                [self.server_config.add_dependency(shell_dependency) for shell_dependency in shell_dependencies]
+            except UnboundLocalError:
+                # No shell dependencies were passed
+                pass
             [self.server_config.add_dependency(dependency) for dependency in connection_setup['dependencies']]
 
         if 'server_configuration' in connection_setup.keys() or 'server_config' in connection_setup.keys():
@@ -462,9 +490,10 @@ class Configuration:
                 c = connection_setup['server_configuration']
             except:
                 c = connection_setup['server_config']
-            if 'enable_service' in c.keys():
-                [self.server_config.add_optional_configuration('enable_service', service) for service in c['enable_service']]
-            [self.server_config.add_optional_configuration(command, param) for command, param in c.items() if command != 'enable_service']
+            if c:
+                if 'enable_service' in c.keys():
+                    [self.server_config.add_optional_configuration('enable_service', service) for service in c['enable_service']]
+                [self.server_config.add_optional_configuration(command, param) for command, param in c.items() if command != 'enable_service']
         if 'configurations' in connection_setup.keys():
             [self.server_config.add_external_script(script) for script in connection_setup['configurations']]
 
